@@ -95,6 +95,7 @@ typedef struct {
 
 static FileTypeDescription write_type_desc[] = { 
 	{ N_("Automatic"),                             NULL},
+	{ N_("Ar (.ar)"),                              ".ar" },
 	{ N_("Arj (.arj)"),                            ".arj" },
 	{ N_("Ear (.ear)"),                            ".ear" },
 	{ N_("Jar (.jar)"),                            ".jar" },
@@ -108,7 +109,8 @@ static FileTypeDescription write_type_desc[] = {
 	{ N_("Tar compressed with compress (.tar.Z)"), ".tar.Z" }, 
 	{ N_("War (.war)"),                            ".war" },
 	{ N_("Zip (.zip)"),                            ".zip" },
-	{ N_("Zoo (.zoo)"),                            ".zoo" }
+	{ N_("Zoo (.zoo)"),                            ".zoo" },
+	{ N_("7-Zip (.7z)"),                            ".7z" }
 };
 
 
@@ -265,22 +267,24 @@ activate_action_new (GtkAction *action,
 		     gpointer   data)
 {
 	static const char * save_mime_type[] = {
-		"application/x-tar",
-		"application/x-compressed-tar",
-		"application/x-bzip-compressed-tar",
+		"application/x-ar",
 		"application/x-arj",
-		"application/zip",
+		"application/x-bzip",
+		"application/x-bzip-compressed-tar",
+		"application/x-cd-image",
+		"application/x-compress",
+		"application/x-compressed-tar",
+		"application/x-gzip",
 		"application/x-java-archive",
 		"application/x-jar",
 		"application/x-lha",
+		"application/x-lzop",
 		"application/x-rar",
 		"application/x-rar-compressed",
-		"application/x-gzip",
-		"application/x-bzip",
-		"application/x-compress",
-		"application/x-lzop",
+		"application/x-tar",
 		"application/x-zoo",
-		"application/x-cd-image",
+		"application/zip",
+		"application/x-7zip"
 	};
 	FRWindow  *window = data;
 	GtkWidget *file_sel;
@@ -392,26 +396,29 @@ activate_action_open (GtkAction *action,
 		      gpointer   data)
 {
 	static const char * open_mime_type[] = {
-		"application/x-tar",
-		"application/x-compressed-tar",
-		"application/x-bzip-compressed-tar",
-		"application/x-lzop-compressed-tar",
+		"application/x-ar",
 		"application/x-arj",
-		"application/zip",
-		"application/x-zip",
+		"application/x-bzip",
+		"application/x-bzip-compressed-tar",
+		"application/x-cd-image",
+		"application/x-compress",
+		"application/x-compressed-tar",
+		"application/x-deb",
+		"application/x-gzip",
+		"application/x-jar",
+		"application/x-java-archive",
 		"application/x-lha",
+		"application/x-lzop",
+		"application/x-lzop-compressed-tar",
 		"application/x-rar",
 		"application/x-rar-compressed",
 		"application/x-rpm",
 		"application/x-stuffit",
-		"application/x-gzip",
-		"application/x-bzip",
-		"application/x-compress",
-		"application/x-lzop",
+		"application/x-tar",
+		"application/x-zip",
 		"application/x-zoo",
-		"application/x-java-archive",
-		"application/x-jar",
-		"application/x-cd-image"
+		"application/zip",
+		"application/x-7zip"
 	};
 	GtkWidget     *file_sel;
 	FRWindow      *window = data;
@@ -581,22 +588,24 @@ activate_action_save_as (GtkAction *action,
 			 gpointer   data)
 {
 	static const char * save_mime_type[] = {
-		"application/x-tar",
-		"application/x-compressed-tar",
-		"application/x-bzip-compressed-tar",
+		"application/x-ar",
 		"application/x-arj",
-		"application/zip",
-		"application/x-java-archive",
-		"application/x-jar",
+		"application/x-bzip",
+		"application/x-bzip-compressed-tar",
+		"application/x-cd-image",
+		"application/x-compress",
+		"application/x-compressed-tar",
+		"application/x-gzip",
 		"application/x-lha",
+		"application/x-lzop",
+		"application/x-jar",
+		"application/x-java-archive",
 		"application/x-rar",
 		"application/x-rar-compressed",
-		"application/x-gzip",
-		"application/x-bzip",
-		"application/x-compress",
-		"application/x-lzop",
+		"application/x-tar",
 		"application/x-zoo",
-		"application/x-cd-image",
+		"application/zip",
+		"application/x-7zip"
 	};
 	FRWindow  *window = data;
 	GtkWidget *file_sel;
@@ -1260,7 +1269,6 @@ activate_action_about (GtkAction *action,
 {
 	FRWindow         *window = data;
 	static GtkWidget *about = NULL;
-	GdkPixbuf        *logo;
 	const char       *authors[] = {
 		"Paolo Bacchilega <paolo.bacchilega@libero.it>", NULL
 	};
@@ -1271,22 +1279,26 @@ activate_action_about (GtkAction *action,
 	};
 	const char       *translator_credits = _("translator_credits");
 
+
 	if (about != NULL) {
 		gtk_window_present (GTK_WINDOW (about));
 		return;
 	}
 
-	logo = gdk_pixbuf_new_from_file (PIXMAPSDIR "/file-roller.png", NULL);
-	about = gnome_about_new (_("File Roller"), 
-				 VERSION,
-				 "Copyright \xc2\xa9 2001-2003 Free Software Foundation, Inc.",
-				 _("An archive manager for GNOME."),
-				 authors,
-				 documenters,
-				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-				 logo);
-	if (logo != NULL)
-                g_object_unref (logo);
+	about = gtk_about_dialog_new ();
+	g_object_set (about,
+		      "name",  _("File Roller"),
+		      "version", VERSION,
+		      "copyright", "Copyright \xc2\xa9 2001-2004 Free Software Foundation, Inc.",
+		      "comments", _("An archive manager for GNOME."),
+		      "authors", authors,
+		      "documenters", documenters,
+		      "translator_credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+		      "logo_icon_name", "file-roller",
+		      "website", NULL,
+		      "website_label", NULL,
+		      "license", NULL,
+		      NULL);
 
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (about), TRUE);
 	gtk_window_set_transient_for (GTK_WINDOW (about), 
@@ -1297,5 +1309,5 @@ activate_action_about (GtkAction *action,
 			  G_CALLBACK (gtk_widget_destroyed), 
 			  &about);
 
-	gtk_widget_show_all (about);
+	gtk_widget_show (about);
 }
